@@ -11,27 +11,28 @@
 #    define QT_END_NAMESPACE
 #endif
 
-#define USR_DATA_PATH ".hydrogen/data"
-#define SYS_DATA_PATH "/usr/share/hydrogen/data"
+#define H2_USR_PATH ".hydrogen"
+#define H2_SYS_PATH "/usr/share/hydrogen"
 #define CONFIG_PREFIX "/usr"
 
-#define H2CORE_VERSION_MAJOR 0
-#define H2CORE_VERSION_MINOR 9
-#define H2CORE_VERSION_PATCH 7
+#define H2CORE_VERSION_MAJOR 1
+#define H2CORE_VERSION_MINOR 1
+#define H2CORE_VERSION_PATCH 0
 
 #define H2CORE_GIT_REVISION 
-#define H2CORE_VERSION "0.9.7"
+#define H2CORE_VERSION "1.1.0-"
+
 
 #define MAX_INSTRUMENTS 1000
 #define MAX_COMPONENTS  32
 #define MAX_NOTES       192
-#define MAX_LAYERS      16
 #define MAX_FX          4
 #define MAX_BUFFER_SIZE 8192
 
 #define HAVE_SSCANF
 #define HAVE_RTCLOCK
 #define HAVE_JACK_PORT_RENAME
+#define HAVE_EXECINFO_H
 
 #ifndef H2CORE_HAVE_DEBUG
 /* #undef H2CORE_HAVE_DEBUG */
@@ -58,10 +59,10 @@
 /* #undef H2CORE_HAVE_LASH */
 #endif
 #ifndef H2CORE_HAVE_JACKSESSION
-#define H2CORE_HAVE_JACKSESSION
+/* #undef H2CORE_HAVE_JACKSESSION */
 #endif
-#ifndef H2CORE_HAVE_NSMSESSION
-#define H2CORE_HAVE_NSMSESSION
+#ifndef H2CORE_HAVE_OSC
+#define H2CORE_HAVE_OSC
 #endif
 #ifndef H2CORE_HAVE_PORTAUDIO
 #define H2CORE_HAVE_PORTAUDIO
